@@ -1,7 +1,8 @@
+from coveo_systools.subprocess import async_check_output
+
 from coveo_stew.ci.runner import ContinuousIntegrationRunner, RunnerStatus
 from coveo_stew.environment import PythonEnvironment, PythonTool
-from coveo_stew.metadata.pyproject_api import PythonProjectAPI
-from coveo_systools.subprocess import check_output
+from coveo_stew.stew import PythonProject
 
 
 class PytestRunner(ContinuousIntegrationRunner):
@@ -14,17 +15,13 @@ class PytestRunner(ContinuousIntegrationRunner):
         *,
         marker_expression: str = None,
         doctest_modules: bool = True,
-        _pyproject: PythonProjectAPI,
+        _pyproject: PythonProject,
     ) -> None:
         super().__init__(_pyproject=_pyproject)
         self.marker_expression = marker_expression
         self.doctest_modules: bool = doctest_modules
 
-    def _launch(self, environment: PythonEnvironment, *extra_args: str) -> RunnerStatus:
-        if not environment.pytest_executable.exists():
-            self._last_output.append("pytest executable could not be found")
-            return RunnerStatus.Error
-
+    async def _launch(self, environment: PythonEnvironment, *extra_args: str) -> RunnerStatus:
         command = environment.build_command(
             PythonTool.Pytest,
             "--durations=5",
@@ -37,7 +34,7 @@ class PytestRunner(ContinuousIntegrationRunner):
         if self.doctest_modules:
             command.append("--doctest-modules")
 
-        check_output(
+        await async_check_output(
             *command,
             *extra_args,
             working_directory=self._pyproject.project_path,
