@@ -242,6 +242,11 @@ class Run:
                     await runner.launch(self.environment, auto_fix=auto_fix), feedback=feedback
                 )
 
+        if self.exceptions:
+            for check, exception in self.exceptions:
+                echo.warning(f"The runner {check} created an exception: ", pad_before=True)
+                echo.noise(exception, pad_after=True)
+
     def _report(self, check: ContinuousIntegrationRunner, feedback: bool = True) -> None:
         """Reports on a completed check."""
         if check.status is RunnerStatus.Error:
@@ -250,6 +255,8 @@ class Run:
         if feedback:
             if check.status is RunnerStatus.Success:
                 echo.normal(f"PASSED: {check}", emoji="heavy_check_mark", fg="green")
+                if check.project.verbose:
+                    check.echo_last_failures()
 
             elif check.status is RunnerStatus.CheckFailed:
                 echo.warning(
@@ -264,6 +271,7 @@ class Run:
                     f"The ci runner {check} failed to complete "
                     f"due to an environment or configuration error."
                 )
+                check.echo_last_failures()
 
 
 def get_overall_run_status(*runs: Run) -> RunnerStatus:
